@@ -18,8 +18,8 @@ class KlineData(BaseTable):
                            Column('low', Float, comment='low', default=0),
                            Column('high', Float, comment='high', default=0),
                            Column('vol', Float, comment='vol', default=0),
-                           # extend_existing=True,
-                           # autoload=True
+                           extend_existing=True,
+                           autoload=True
                            )
         self.create()
 
