@@ -49,7 +49,7 @@ class LoadDataKline:
         unix_end = unix_end
         unix_max = unix_max or self.exchange.milliseconds()
         unix_min = unix_min or self.exchange.milliseconds()
-        print(unix_start, unix_end, unix_max, unix_max)
+        #print(unix_start, unix_end, unix_max, unix_max)
 
         if unix_min >= unix_start:
             unix_temp = unix_min
